<?php

declare(strict_types=1);

namespace Dedi\SyliusClicAndPayPlugin\Form\Type;

use Dedi\SyliusClicAndPayPlugin\Payum\ClicAndPayParams;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\CheckboxType;
use Symfony\Component\Form\Extension\Core\Type\NumberType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\Validator\Constraints\NotBlank;

class ClicAndPayGatewayConfigurationType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
            ->add(ClicAndPayParams::VADS_SITE_ID, TextType::class, [
                'label' => 'dedi_clic_and_pay.form.identifier',
                'constraints' => [
                    new NotBlank(['groups' => ['default', 'sylius']]),
                ],
            ])
            ->add(ClicAndPayParams::VADS_SITE_KEY, TextType::class, [
                'label' => 'dedi_clic_and_pay.form.key',
                'constraints' => [
                    new NotBlank(['groups' => ['default', 'sylius']]),
                ],
            ])
            ->add('sandbox', CheckboxType::class, [
                'label' => 'dedi_clic_and_pay.form.sandbox',
                'required' => false,
            ])
            ->add(ClicAndPayParams::IS_MULTI_PAYMENT, CheckboxType::class, [
                'label' => 'dedi_clic_and_pay.form.is_multi_payment',
                'required' => false,
            ])
            ->add(ClicAndPayParams::MULTI_PAYMENT_FIRST_PERCENT, NumberType::class, [
                'label' => 'dedi_clic_and_pay.form.multi_payment_first_percent',
                'html5' => true,
                'attr' => ['min' => 1, 'step' => 1, 'max' => 100],
                'required' => false,
            ])
            ->add(ClicAndPayParams::MULTI_PAYMENT_COUNT, NumberType::class, [
                'label' => 'dedi_clic_and_pay.form.multi_payment_count',
                'required' => false,
            ])
            ->add(ClicAndPayParams::MULTI_PAYMENT_PERIOD, NumberType::class, [
                'label' => 'dedi_clic_and_pay.form.multi_payment_period',
                'required' => false,
            ])
        ;
    }
}
